#!/usr/bin/perl
use lib '/home/erealms/ethereal/mgmt/perl';

################################################################################
# Created       : Martin Foster
# Modified      : 10-Sep-2006
################################################################################
#
# Colours - Script part of Ethereal Realms, designed to list all colours
# Copyright (C) 2000-2007  Martin Foster
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
# Author of this script can be contacted at the following:
#       E-Mail  : martin@ethereal-realms.org
#       Address : 4-3526 Wolfe Cres
#                 Halifax, Nova Scotia
#                 B3L 3S2
#
#################################################################################

use CGI qw(-no_debug -nosticky);				# Common gateway interface
use CGI::Carp qw(fatalsToBrowser);				# CGI Error logs
use strict;							# Strict variable enforcement

use Ethereal::Comm;						# Communications panel
use Ethereal::Database;						# Database handler
use Ethereal::Login;						# Login functionality
use Ethereal::Param;						# Parameter control
use Ethereal::Option;						# Option handling
use Ethereal::Template;						# Template file

#################################################################################
# Gobal override
#################################################################################
$CGI::POST_MAX=1024 * 50;					# Maximum posts
$CGI::DISABLE_UPLOADS = 1;					# Disable uploads

################################################################################
# Data Members
################################################################################
my $cgi;							# Common gateway interface handle
my $comm;							# Comm panel
my $database;							# Database handle
my $param;							# Parameter handle
my $scriptname;							# Script name
my $tmpl;							# Template handler

my $res;							# Results list
my $statement;							# Database statement

my $listing   = '';						# Listing of all colours
my $sect      = '';						# Section of font faces

my $name;							# Name individual
my $font;							# Font individual

my @names;							# List of allowed names
my @fonts;							# List of allowed fonts

my %colors;							# Colour codes
my %fonts;							# Fonts handling
my %realm;							# Realm hash


################################################################################
# Program Area
################################################################################

	# Initial handles
	$cgi      = new CGI;
	$database = new Ethereal::Database();

	# Connect and fetch
	$database->Connect($cgi);

	# Parameter handling
	$param    = new Ethereal::Param($database, $cgi);
	$param->GetParam();

	
	# Database handles
	my $data  = $database->{'HANDLE'};
	my $statement;

	# Dependant handles
	$tmpl     = new Ethereal::Template(\%realm);
	$comm     = new Ethereal::Comm($database, $cgi, $tmpl);


	# Connect with hash
	$database->GetHashRealm(\%realm);

	# Retreive lists
	@fonts = $comm->FontSelectFace($param);
	@names = $comm->FontSelectColor($param);


	# Generate hashes - Required to work around realm restrictions
	# Prepare and execute
	$database->Pull(\$statement, "SELECT 
		 FontName AS \"FontName\",
		 FontType AS \"FontType\",
		 FontCode AS \"FontCode\"
		FROM Font
		WHERE FontType IN ('color','face')");
	
	# Cycle through
	while ($res = $statement->fetchrow_hashref())
	{
		# Create elements
		if ($res->{'FontType'} eq 'color')
		{
			# New colour entry
			$colors{$res->{'FontName'}} = $res->{'FontCode'};
		}
		else
		{
			# New face entry
			$fonts{$res->{'FontName'}} = $res->{'FontCode'};
		}
	}

	# Finish
	$statement->finish();



	# Cycle through
	# Known and accepted realm colours
	foreach $name (@names) 
	{
		# Initialize
		$sect = '';

		# Cycle through known and accepted fonts
		foreach $font (@fonts)
		{
			# Generate sub-section
			$sect .= $tmpl->Pass('TmplFontFace',
				MNAME => $font,
				MFACE => $fonts{$font},
				MCOLR => $colors{$name}
			 );	

		}

		# Generate listing
		$listing .= $tmpl->Pass('TmplFontColor',
			LSTFACE => $sect,
			MNAME   => $name,
			MCODE   => $colors{$name},
		 );
	}


	# HTML display
	# Document header
	print $cgi->header();
	print $database->FetchRealmHeader($param->{'ROOM'}), "\n";

	# Display template
	$tmpl->Show('TmplFont',
		LSTCOLOR => $listing
	 );

	# Document footer
	print $database->FetchRealmFooter($param->{'ROOM'}), "\n";
