-- Remove old entry
ALTER TABLE PGSCHEMA.Puppet    DROP COLUMN PuppetDisplay;


-- Contact Information Display
ALTER TABLE PGSCHEMA.Puppeteer ADD COLUMN PuppeteerContact VARCHAR(5);
UPDATE PGSCHEMA.Puppeteer      SET PuppeteerContact='yes';
ALTER TABLE PGSCHEMA.Puppeteer ALTER COLUMN PuppeteerContact  SET NOT NULL;
ALTER TABLE PGSCHEMA.Puppeteer ALTER COLUMN PuppeteerContact  SET DEFAULT 'yes';
ALTER TABLE PGSCHEMA.Puppeteer ADD CONSTRAINT enumPuppeteerContact CHECK (PuppeteerContact IN ('yes','no','limit'));


-- Have to cleanup
DELETE FROM PGSCHEMA.Tag WHERE TagName IN ('TmplPupConfig','TmplUserPref') AND TagType IN 'user';


-- Polling
ALTER TABLE PGSCHEMA.Poll ADD COLUMN RealmName VARCHAR(30);
UPDATE PGSCHEMA.Poll SET RealmName='system';
ALTER TABLE PGSCHEMA.Poll ALTER COLUMN RealmName SET NOT NULL;
ALTER TABLE PGSCHEMA.Poll ALTER COLUMN RealmName SET DEFAULT 'system';
ALTER TABLE PGSCHEMA.Poll ADD CONSTRAINT fkPoll FOREIGN KEY (RealmName)
    REFERENCES PGSCHEMA.Realm (RealmName)
      ON DELETE CASCADE
      ON UPDATE CASCADE;


--
--
-- NAME        : Sign
-- REFERENCES  : NIL
--
-- DESCRIPTION : Chinese astrological signs.

CREATE TABLE PGSCHEMA.Sign (
  SignAnimal         VARCHAR(10)   NOT NULL,
  SignElement        VARCHAR(6)    NOT NULL,
  SignStart          DATE          NOT NULL,
  SignEnd            DATE          NOT NULL,
  CONSTRAINT pkSign               PRIMARY KEY (SignAnimal, SignElement, SignStart)
);

-- STANDARD INDEX
CREATE INDEX idxSign ON PGSCHEMA.Sign
(
  SignStart,
  SignEnd
);


-- Social profile display
ALTER TABLE PGSCHEMA.Puppeteer ADD COLUMN PuppeteerSocial VARCHAR(3);
UPDATE PGSCHEMA.Puppeteer      SET PuppeteerSocial='yes';
ALTER TABLE PGSCHEMA.Puppeteer ALTER COLUMN PuppeteerSocial  SET NOT NULL;
ALTER TABLE PGSCHEMA.Puppeteer ALTER COLUMN PuppeteerSocial  SET DEFAULT 'yes';
ALTER TABLE PGSCHEMA.Puppeteer ADD CONSTRAINT enumPuppeteerSocial CHECK (PuppeteerSocial IN ('yes','no'));


DROP VIEW PGSCHEMA.Network;
CREATE VIEW PGSCHEMA.Network AS
   SELECT
     p.PuppeteerLogin       AS PuppeteerLogin,
     p.PuppeteerTimestamp   AS PuppeteerTimestamp,
     h.PuppetName           AS PuppetName,
     h.PuppetShort          AS PuppetShort,
     h.PuppetGummy          AS PuppetGummy,
     s.LocateCity           AS LocateCity,
     s.LocateRegion         AS LocateRegion,
     s.LocateCountry        AS LocateCountry,
     s.LocateLat            AS LocateLat,
     s.LocateLong           AS LocateLong,
     s.PhysicalGender       AS PhysicalGender,
     s.PhysicalBirthDate    AS PhysicalBirthDate,
     s.PhysicalHeight       AS PhysicalHeight,
     s.PhysicalBodyType     AS PhysicalBodyType,
     s.PhysicalEyeColour    AS PhysicalEyeColour,
     s.PhysicalHairColour   AS PhysicalHairColour,
     s.PhysicalEthnicity    AS PhysicalEthnicity,
     s.IntroCatchPhrase     AS IntroCatchPhrase,
     s.IntroDescription     AS IntroDescription,
     s.IntroFirstDate       AS IntroFirstDate,
     s.SocialLooking        AS SocialLooking,
     s.SocialSeeking        AS SocialSeeking,
     s.SocialAgeMin         AS SocialAgeMin,
     s.SocialAgeMax         AS SocialAgeMax,
     s.SocialMarital        AS SocialMarital,
     s.SocialChildrenHave   AS SocialChildrenHave,
     s.SocialChildrenWant   AS SocialChildrenWant,
     s.SocialInterests      AS SocialInterests,
     s.SocialReligion       AS SocialReligion,
     s.SocialProfession     AS SocialProfession,
     s.ViceSmoke            AS ViceSmoke,
     s.ViceDrink            AS ViceDrink,
     PGSCHEMA.getBirthDay(s.PhysicalBirthDate)   AS PhysicalBirthDay,
     PGSCHEMA.getBirthMonth(s.PhysicalBirthDate) AS PhysicalBirthMonth,
     PGSCHEMA.getBirthYear(s.PhysicalBirthDate)  AS PhysicalBirthYear,
     PGSCHEMA.getAge(s.PhysicalBirthDate)        AS PhysicalAge
  FROM PGSCHEMA.Social s, PGSCHEMA.Puppeteer p, PGSCHEMA.Puppet h
  WHERE (h.PuppetDefault  = 'yes'
     AND h.PuppetPool     = 'system'
     AND s.PuppeteerLogin = h.PuppeteerLogin)
    AND s.PuppeteerLogin = P.PuppeteerLogin
    AND p.PuppeteerSocial='yes';